<?php

if ( ! function_exists( 'holmes_mkdf_get_hide_dep_for_full_screen_menu_options' ) ) {
	function holmes_mkdf_get_hide_dep_for_full_screen_menu_options() {
		$hide_dep_options = apply_filters( 'holmes_mkdf_full_screen_menu_hide_global_option', $hide_dep_options = array() );
		
		return $hide_dep_options;
	}
}

if ( ! function_exists( 'holmes_mkdf_fullscreen_menu_options_map' ) ) {
	function holmes_mkdf_fullscreen_menu_options_map() {
		$hide_dep_options = holmes_mkdf_get_hide_dep_for_full_screen_menu_options();
		
		$fullscreen_panel = holmes_mkdf_add_admin_panel(
			array(
				'title'           => esc_html__( 'Full Screen Menu', 'holmes' ),
				'name'            => 'panel_fullscreen_menu',
				'page'            => '_header_page',
				'dependency' => array(
					'hide' => array(
						'header_options'  => $hide_dep_options
					)
				)
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $fullscreen_panel,
				'type'          => 'select',
				'name'          => 'fullscreen_menu_animation_style',
				'default_value' => 'fade-push-text-right',
				'label'         => esc_html__( 'Full Screen Menu Overlay Animation', 'holmes' ),
				'description'   => esc_html__( 'Choose animation type for full screen menu overlay', 'holmes' ),
				'options'       => array(
					'fade-push-text-right' => esc_html__( 'Fade Push Text Right', 'holmes' ),
					'fade-push-text-top'   => esc_html__( 'Fade Push Text Top', 'holmes' ),
					'fade-text-scaledown'  => esc_html__( 'Fade Text Scaledown', 'holmes' )
				)
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $fullscreen_panel,
				'type'          => 'yesno',
				'name'          => 'fullscreen_in_grid',
				'default_value' => 'no',
				'label'         => esc_html__( 'Full Screen Menu in Grid', 'holmes' ),
				'description'   => esc_html__( 'Enabling this option will put full screen menu content in grid', 'holmes' ),
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $fullscreen_panel,
				'type'          => 'selectblank',
				'name'          => 'fullscreen_alignment',
				'default_value' => '',
				'label'         => esc_html__( 'Full Screen Menu Alignment', 'holmes' ),
				'description'   => esc_html__( 'Choose alignment for full screen menu content', 'holmes' ),
				'options'       => array(
					''       => esc_html__( 'Default', 'holmes' ),
					'left'   => esc_html__( 'Left', 'holmes' ),
					'center' => esc_html__( 'Center', 'holmes' ),
					'right'  => esc_html__( 'Right', 'holmes' )
				)
			)
		);
		
		$background_group = holmes_mkdf_add_admin_group(
			array(
				'parent'      => $fullscreen_panel,
				'name'        => 'background_group',
				'title'       => esc_html__( 'Background', 'holmes' ),
				'description' => esc_html__( 'Select a background color and transparency for full screen menu (0 = fully transparent, 1 = opaque)', 'holmes' )
			)
		);
		
		$background_group_row = holmes_mkdf_add_admin_row(
			array(
				'parent' => $background_group,
				'name'   => 'background_group_row'
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent' => $background_group_row,
				'type'   => 'colorsimple',
				'name'   => 'fullscreen_menu_background_color',
				'label'  => esc_html__( 'Background Color', 'holmes' )
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent' => $background_group_row,
				'type'   => 'textsimple',
				'name'   => 'fullscreen_menu_background_transparency',
				'label'  => esc_html__( 'Background Transparency', 'holmes' )
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'      => $fullscreen_panel,
				'type'        => 'image',
				'name'        => 'fullscreen_menu_background_image',
				'label'       => esc_html__( 'Background Image', 'holmes' ),
				'description' => esc_html__( 'Choose a background image for full screen menu background', 'holmes' )
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'      => $fullscreen_panel,
				'type'        => 'image',
				'name'        => 'fullscreen_menu_pattern_image',
				'label'       => esc_html__( 'Pattern Background Image', 'holmes' ),
				'description' => esc_html__( 'Choose a pattern image for full screen menu background', 'holmes' )
			)
		);
		
		//1st level style group
		$first_level_style_group = holmes_mkdf_add_admin_group(
			array(
				'parent'      => $fullscreen_panel,
				'name'        => 'first_level_style_group',
				'title'       => esc_html__( '1st Level Style', 'holmes' ),
				'description' => esc_html__( 'Define styles for 1st level in full screen menu', 'holmes' )
			)
		);
		
		$first_level_style_row1 = holmes_mkdf_add_admin_row(
			array(
				'parent' => $first_level_style_group,
				'name'   => 'first_level_style_row1'
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $first_level_style_row1,
				'type'          => 'colorsimple',
				'name'          => 'fullscreen_menu_color',
				'default_value' => '',
				'label'         => esc_html__( 'Text Color', 'holmes' ),
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $first_level_style_row1,
				'type'          => 'colorsimple',
				'name'          => 'fullscreen_menu_hover_color',
				'default_value' => '',
				'label'         => esc_html__( 'Hover Text Color', 'holmes' ),
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $first_level_style_row1,
				'type'          => 'colorsimple',
				'name'          => 'fullscreen_menu_active_color',
				'default_value' => '',
				'label'         => esc_html__( 'Active Text Color', 'holmes' ),
			)
		);
		
		$first_level_style_row3 = holmes_mkdf_add_admin_row(
			array(
				'parent' => $first_level_style_group,
				'name'   => 'first_level_style_row3'
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $first_level_style_row3,
				'type'          => 'fontsimple',
				'name'          => 'fullscreen_menu_google_fonts',
				'default_value' => '-1',
				'label'         => esc_html__( 'Font Family', 'holmes' ),
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $first_level_style_row3,
				'type'          => 'textsimple',
				'name'          => 'fullscreen_menu_font_size',
				'default_value' => '',
				'label'         => esc_html__( 'Font Size', 'holmes' ),
				'args'          => array(
					'suffix' => 'px'
				)
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $first_level_style_row3,
				'type'          => 'textsimple',
				'name'          => 'fullscreen_menu_line_height',
				'default_value' => '',
				'label'         => esc_html__( 'Line Height', 'holmes' ),
				'args'          => array(
					'suffix' => 'px'
				)
			)
		);
		
		$first_level_style_row4 = holmes_mkdf_add_admin_row(
			array(
				'parent' => $first_level_style_group,
				'name'   => 'first_level_style_row4'
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $first_level_style_row4,
				'type'          => 'selectblanksimple',
				'name'          => 'fullscreen_menu_font_style',
				'default_value' => '',
				'label'         => esc_html__( 'Font Style', 'holmes' ),
				'options'       => holmes_mkdf_get_font_style_array()
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $first_level_style_row4,
				'type'          => 'selectblanksimple',
				'name'          => 'fullscreen_menu_font_weight',
				'default_value' => '',
				'label'         => esc_html__( 'Font Weight', 'holmes' ),
				'options'       => holmes_mkdf_get_font_weight_array()
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $first_level_style_row4,
				'type'          => 'textsimple',
				'name'          => 'fullscreen_menu_letter_spacing',
				'default_value' => '',
				'label'         => esc_html__( 'Lettert Spacing', 'holmes' ),
				'args'          => array(
					'suffix' => 'px'
				)
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $first_level_style_row4,
				'type'          => 'selectblanksimple',
				'name'          => 'fullscreen_menu_text_transform',
				'default_value' => '',
				'label'         => esc_html__( 'Text Transform', 'holmes' ),
				'options'       => holmes_mkdf_get_text_transform_array()
			)
		);
		
		//2nd level style group
		$second_level_style_group = holmes_mkdf_add_admin_group(
			array(
				'parent'      => $fullscreen_panel,
				'name'        => 'second_level_style_group',
				'title'       => esc_html__( '2nd Level Style', 'holmes' ),
				'description' => esc_html__( 'Define styles for 2nd level in full screen menu', 'holmes' )
			)
		);
		
		$second_level_style_row1 = holmes_mkdf_add_admin_row(
			array(
				'parent' => $second_level_style_group,
				'name'   => 'second_level_style_row1'
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $second_level_style_row1,
				'type'          => 'colorsimple',
				'name'          => 'fullscreen_menu_color_2nd',
				'default_value' => '',
				'label'         => esc_html__( 'Text Color', 'holmes' ),
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $second_level_style_row1,
				'type'          => 'colorsimple',
				'name'          => 'fullscreen_menu_hover_color_2nd',
				'default_value' => '',
				'label'         => esc_html__( 'Hover/Active Text Color', 'holmes' ),
			)
		);
		
		$second_level_style_row2 = holmes_mkdf_add_admin_row(
			array(
				'parent' => $second_level_style_group,
				'name'   => 'second_level_style_row2'
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $second_level_style_row2,
				'type'          => 'fontsimple',
				'name'          => 'fullscreen_menu_google_fonts_2nd',
				'default_value' => '-1',
				'label'         => esc_html__( 'Font Family', 'holmes' ),
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $second_level_style_row2,
				'type'          => 'textsimple',
				'name'          => 'fullscreen_menu_font_size_2nd',
				'default_value' => '',
				'label'         => esc_html__( 'Font Size', 'holmes' ),
				'args'          => array(
					'suffix' => 'px'
				)
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $second_level_style_row2,
				'type'          => 'textsimple',
				'name'          => 'fullscreen_menu_line_height_2nd',
				'default_value' => '',
				'label'         => esc_html__( 'Line Height', 'holmes' ),
				'args'          => array(
					'suffix' => 'px'
				)
			)
		);
		
		$second_level_style_row3 = holmes_mkdf_add_admin_row(
			array(
				'parent' => $second_level_style_group,
				'name'   => 'second_level_style_row3'
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $second_level_style_row3,
				'type'          => 'selectblanksimple',
				'name'          => 'fullscreen_menu_font_style_2nd',
				'default_value' => '',
				'label'         => esc_html__( 'Font Style', 'holmes' ),
				'options'       => holmes_mkdf_get_font_style_array()
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $second_level_style_row3,
				'type'          => 'selectblanksimple',
				'name'          => 'fullscreen_menu_font_weight_2nd',
				'default_value' => '',
				'label'         => esc_html__( 'Font Weight', 'holmes' ),
				'options'       => holmes_mkdf_get_font_weight_array()
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $second_level_style_row3,
				'type'          => 'textsimple',
				'name'          => 'fullscreen_menu_letter_spacing_2nd',
				'default_value' => '',
				'label'         => esc_html__( 'Lettert Spacing', 'holmes' ),
				'args'          => array(
					'suffix' => 'px'
				)
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $second_level_style_row3,
				'type'          => 'selectblanksimple',
				'name'          => 'fullscreen_menu_text_transform_2nd',
				'default_value' => '',
				'label'         => esc_html__( 'Text Transform', 'holmes' ),
				'options'       => holmes_mkdf_get_text_transform_array()
			)
		);
		
		$third_level_style_group = holmes_mkdf_add_admin_group(
			array(
				'parent'      => $fullscreen_panel,
				'name'        => 'third_level_style_group',
				'title'       => esc_html__( '3rd Level Style', 'holmes' ),
				'description' => esc_html__( 'Define styles for 3rd level in full screen menu', 'holmes' )
			)
		);
		
		$third_level_style_row1 = holmes_mkdf_add_admin_row(
			array(
				'parent' => $third_level_style_group,
				'name'   => 'third_level_style_row1'
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $third_level_style_row1,
				'type'          => 'colorsimple',
				'name'          => 'fullscreen_menu_color_3rd',
				'default_value' => '',
				'label'         => esc_html__( 'Text Color', 'holmes' ),
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $third_level_style_row1,
				'type'          => 'colorsimple',
				'name'          => 'fullscreen_menu_hover_color_3rd',
				'default_value' => '',
				'label'         => esc_html__( 'Hover/Active Text Color', 'holmes' ),
			)
		);
		
		$third_level_style_row2 = holmes_mkdf_add_admin_row(
			array(
				'parent' => $third_level_style_group,
				'name'   => 'second_level_style_row2'
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $third_level_style_row2,
				'type'          => 'fontsimple',
				'name'          => 'fullscreen_menu_google_fonts_3rd',
				'default_value' => '-1',
				'label'         => esc_html__( 'Font Family', 'holmes' ),
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $third_level_style_row2,
				'type'          => 'textsimple',
				'name'          => 'fullscreen_menu_font_size_3rd',
				'default_value' => '',
				'label'         => esc_html__( 'Font Size', 'holmes' ),
				'args'          => array(
					'suffix' => 'px'
				)
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $third_level_style_row2,
				'type'          => 'textsimple',
				'name'          => 'fullscreen_menu_line_height_3rd',
				'default_value' => '',
				'label'         => esc_html__( 'Line Height', 'holmes' ),
				'args'          => array(
					'suffix' => 'px'
				)
			)
		);
		
		$third_level_style_row3 = holmes_mkdf_add_admin_row(
			array(
				'parent' => $third_level_style_group,
				'name'   => 'second_level_style_row3'
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $third_level_style_row3,
				'type'          => 'selectblanksimple',
				'name'          => 'fullscreen_menu_font_style_3rd',
				'default_value' => '',
				'label'         => esc_html__( 'Font Style', 'holmes' ),
				'options'       => holmes_mkdf_get_font_style_array()
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $third_level_style_row3,
				'type'          => 'selectblanksimple',
				'name'          => 'fullscreen_menu_font_weight_3rd',
				'default_value' => '',
				'label'         => esc_html__( 'Font Weight', 'holmes' ),
				'options'       => holmes_mkdf_get_font_weight_array()
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $third_level_style_row3,
				'type'          => 'textsimple',
				'name'          => 'fullscreen_menu_letter_spacing_3rd',
				'default_value' => '',
				'label'         => esc_html__( 'Lettert Spacing', 'holmes' ),
				'args'          => array(
					'suffix' => 'px'
				)
			)
		);
		
		holmes_mkdf_add_admin_field(
			array(
				'parent'        => $third_level_style_row3,
				'type'          => 'selectblanksimple',
				'name'          => 'fullscreen_menu_text_transform_3rd',
				'default_value' => '',
				'label'         => esc_html__( 'Text Transform', 'holmes' ),
				'options'       => holmes_mkdf_get_text_transform_array()
			)
		);
	}
	
	add_action( 'holmes_mkdf_additional_header_menu_area_options_map', 'holmes_mkdf_fullscreen_menu_options_map' );
}