<?php

namespace HolmesCore\CPT\Shortcodes\ProductList;

use HolmesCore\Lib;

class ProductList implements Lib\ShortcodeInterface {
	private $base;

	function __construct() {
		$this->base = 'mkdf_product_list';

		add_action( 'vc_before_init', array( $this, 'vcMap' ) );
	}

	public function getBase() {
		return $this->base;
	}

	public function vcMap() {
		if ( function_exists( 'vc_map' ) ) {
			vc_map(
				array(
					'name'                      => esc_html__( 'Product List', 'holmes' ),
					'base'                      => $this->base,
					'icon'                      => 'icon-wpb-product-list extended-custom-icon',
					'category'                  => esc_html__( 'by HOLMES', 'holmes' ),
					'allowed_container_element' => 'vc_row',
					'params'                    => array(
						array(
							'type'       => 'textfield',
							'param_name' => 'number_of_posts',
							'heading'    => esc_html__( 'Number of Products', 'holmes' )
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'number_of_columns',
							'heading'     => esc_html__( 'Number of Columns', 'holmes' ),
							'value'       => array_flip( holmes_mkdf_get_number_of_columns_array( true ) ),
							'save_always' => true
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'space_between_items',
							'heading'     => esc_html__( 'Space Between Items', 'holmes' ),
							'value'       => array_flip( holmes_mkdf_get_space_between_items_array() ),
							'save_always' => true
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'orderby',
							'heading'     => esc_html__( 'Order By', 'holmes' ),
							'value'       => array_flip( holmes_mkdf_get_query_order_by_array( false, array( 'on-sale' => esc_html__( 'On Sale', 'holmes' ) ) ) ),
							'save_always' => true
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'order',
							'heading'     => esc_html__( 'Order', 'holmes' ),
							'value'       => array_flip( holmes_mkdf_get_query_order_array() ),
							'save_always' => true
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'taxonomy_to_display',
							'heading'     => esc_html__( 'Choose Sorting Taxonomy', 'holmes' ),
							'value'       => array(
								esc_html__( 'Category', 'holmes' ) => 'category',
								esc_html__( 'Tag', 'holmes' )      => 'tag',
								esc_html__( 'Id', 'holmes' )       => 'id'
							),
							'save_always' => true,
							'description' => esc_html__( 'If you would like to display only certain products, this is where you can select the criteria by which you would like to choose which products to display', 'holmes' )
						),
						array(
							'type'        => 'textfield',
							'param_name'  => 'taxonomy_values',
							'heading'     => esc_html__( 'Enter Taxonomy Values', 'holmes' ),
							'description' => esc_html__( 'Separate values (category slugs, tags, or post IDs) with a comma', 'holmes' )
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'image_size',
							'heading'     => esc_html__( 'Image Proportions', 'holmes' ),
							'value'       => array(
								esc_html__( 'Default', 'holmes' )        => '',
								esc_html__( 'Original', 'holmes' )       => 'full',
								esc_html__( 'Square', 'holmes' )         => 'square',
								esc_html__( 'Landscape', 'holmes' )      => 'landscape',
								esc_html__( 'Portrait', 'holmes' )       => 'portrait',
								esc_html__( 'Medium', 'holmes' )         => 'medium',
								esc_html__( 'Large', 'holmes' )          => 'large',
								esc_html__( 'Shop Single', 'holmes' )    => 'woocommerce_single',
								esc_html__( 'Shop Thumbnail', 'holmes' ) => 'woocommerce_thumbnail'
							),
							'save_always' => true
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'display_title',
							'heading'    => esc_html__( 'Display Title', 'holmes' ),
							'value'      => array_flip( holmes_mkdf_get_yes_no_select_array( false, true ) ),
							'group'      => esc_html__( 'Product Info', 'holmes' )
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'title_tag',
							'heading'    => esc_html__( 'Title Tag', 'holmes' ),
							'value'      => array_flip( holmes_mkdf_get_title_tag( true ) ),
							'dependency' => array( 'element' => 'display_title', 'value' => array( 'yes' ) ),
							'group'      => esc_html__( 'Product Info Style', 'holmes' )
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'title_transform',
							'heading'    => esc_html__( 'Title Text Transform', 'holmes' ),
							'value'      => array_flip( holmes_mkdf_get_text_transform_array( true ) ),
							'dependency' => array( 'element' => 'display_title', 'value' => array( 'yes' ) ),
							'group'      => esc_html__( 'Product Info Style', 'holmes' )
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'display_rating',
							'heading'    => esc_html__( 'Display Rating', 'holmes' ),
							'value'      => array_flip( holmes_mkdf_get_yes_no_select_array( false, true ) ),
							'group'      => esc_html__( 'Product Info', 'holmes' )
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'display_price',
							'heading'    => esc_html__( 'Display Price', 'holmes' ),
							'value'      => array_flip( holmes_mkdf_get_yes_no_select_array( false, true ) ),
							'group'      => esc_html__( 'Product Info', 'holmes' )
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'display_button',
							'heading'    => esc_html__( 'Display Button', 'holmes' ),
							'value'      => array_flip( holmes_mkdf_get_yes_no_select_array( false, true ) ),
							'group'      => esc_html__( 'Product Info', 'holmes' )
						),
					)
				)
			);
		}
	}

	public function render( $atts, $content = null ) {
		$default_atts = array(
			'type'                => 'standard',
			//'info_position'       => 'info-on-image',
			'number_of_posts'     => '8',
			'number_of_columns'   => 'four',
			'space_between_items' => 'normal',
			'orderby'             => 'date',
			'order'               => 'ASC',
			'taxonomy_to_display' => 'category',
			'taxonomy_values'     => '',
			'image_size'          => 'full',
			'display_title'       => 'yes',
			//'product_info_skin'       => '',
			'title_tag'           => 'h5',
			'title_transform'     => '',
			//'display_category'        => 'no',
			//'display_excerpt'         => 'no',
			//'excerpt_length'          => '20',
			'display_rating'      => 'yes',
			'display_price'       => 'yes',
			'display_button'      => 'yes',
			//'button_skin'             => 'default',
			//'shader_background_color' => '',
			//'info_bottom_text_align'  => '',
			//'info_bottom_margin'      => ''
		);
		$params       = shortcode_atts( $default_atts, $atts );

		$params['class_name'] = 'pli';
		$params['type']       = ! empty( $params['type'] ) ? $params['type'] : $default_atts['type'];
		//$params['info_position'] = ! empty( $params['info_position'] ) ? $params['info_position'] : $default_atts['info_position'];
		$params['title_tag'] = ! empty( $params['title_tag'] ) ? $params['title_tag'] : $default_atts['title_tag'];

		$additional_params                   = array();
		$additional_params['holder_classes'] = $this->getHolderClasses( $params, $default_atts );

		$queryArray                        = $this->generateProductQueryArray( $params );
		$query_result                      = new \WP_Query( $queryArray );
		$additional_params['query_result'] = $query_result;

		$params['this_object'] = $this;

		$html = holmes_mkdf_get_woo_shortcode_module_template_part( 'templates/product-list', 'product-list', $params['type'], $params, $additional_params );

		return $html;
	}

	private function getHolderClasses( $params, $default_atts ) {
		$holderClasses   = array();
		$holderClasses[] = ! empty( $params['type'] ) ? 'mkdf-' . $params['type'] . '-layout' : 'mkdf-' . $default_atts['type'] . '-layout';
		$holderClasses[] = ! empty( $params['number_of_columns'] ) ? 'mkdf-' . $params['number_of_columns'] . '-columns' : 'mkdf-' . $default_atts['number_of_columns'] . '-columns';
		$holderClasses[] = ! empty( $params['space_between_items'] ) ? 'mkdf-' . $params['space_between_items'] . '-space' : 'mkdf-' . $default_atts['space_between_items'] . '-space';
		//$holderClasses[] = ! empty( $params['info_position'] ) ? 'mkdf-' . $params['info_position'] : 'mkdf-' . $default_atts['info_position'];
		$holderClasses[] = ! empty( $params['product_info_skin'] ) ? 'mkdf-product-info-' . $params['product_info_skin'] : '';

		return implode( ' ', $holderClasses );
	}

	private function generateProductQueryArray( $params ) {
		$queryArray = array(
			'post_status'         => 'publish',
			'post_type'           => 'product',
			'ignore_sticky_posts' => 1,
			'posts_per_page'      => $params['number_of_posts'],
			'orderby'             => $params['orderby'],
			'order'               => $params['order']
		);

		if ( $params['orderby'] === 'on-sale' ) {
			$queryArray['no_found_rows'] = 1;
			$queryArray['post__in']      = array_merge( array( 0 ), wc_get_product_ids_on_sale() );
		}

		if ( $params['taxonomy_to_display'] !== '' && $params['taxonomy_to_display'] === 'category' ) {
			$queryArray['product_cat'] = $params['taxonomy_values'];
		}

		if ( $params['taxonomy_to_display'] !== '' && $params['taxonomy_to_display'] === 'tag' ) {
			$queryArray['product_tag'] = $params['taxonomy_values'];
		}

		if ( $params['taxonomy_to_display'] !== '' && $params['taxonomy_to_display'] === 'id' ) {
			$idArray                = $params['taxonomy_values'];
			$ids                    = explode( ',', $idArray );
			$queryArray['post__in'] = $ids;
		}

		return $queryArray;
	}

	public function getItemClasses( $params ) {
		$itemClasses = array();

		$image_size_meta = get_post_meta( get_the_ID(), 'mkdf_product_featured_image_size', true );

		if ( ! empty( $image_size_meta ) ) {
			$itemClasses[] = 'mkdf-fixed-masonry-item mkdf-masonry-size-' . $image_size_meta;
		}

		return implode( ' ', $itemClasses );
	}

	public function getTitleStyles( $params ) {
		$styles = array();

		if ( ! empty( $params['title_transform'] ) ) {
			$styles[] = 'text-transform: ' . $params['title_transform'];
		}

		return implode( ';', $styles );
	}

	public function getShaderStyles( $params ) {
		$styles = array();

		if ( ! empty( $params['shader_background_color'] ) ) {
			$styles[] = 'background-color: ' . $params['shader_background_color'];
		}

		return implode( ';', $styles );
	}

	public function getTextWrapperStyles( $params ) {
		$styles = array();

		if ( ! empty( $params['info_bottom_text_align'] ) ) {
			$styles[] = 'text-align: ' . $params['info_bottom_text_align'];
		}

		if ( $params['info_bottom_margin'] !== '' ) {
			$styles[] = 'margin-bottom: ' . holmes_mkdf_filter_px( $params['info_bottom_margin'] ) . 'px';
		}

		return implode( ';', $styles );
	}
}